Changelog
=========

next
----
#. Django 2 and Python 3.5 compatibility. Django 1.9 is no longer supported.

0.2
---
#. Move to tox for tests.
#. Django 1.9 to 1.11 support. The official minimum supported version is 1.9.

0.1
---
#. Cleanup and fixing of tests courtesy of senyor.
#. Rewrite distinct query so it works with Oracle backend.

0.0.6
-----
#. Better packaging.

0.0.5 (2011-08-17)
------------------
#. Added sites support.
#. Added unittests.

0.0.4 (2011-08-11)
------------------
#. Cleanup. Docs polish.

0.0.3
-----
#. Spelling correction, thanks tiktuk.

0.0.2
-----
#. Doc update to indicate importance of placing url include before admin url include.

0.0.1
-----
#. First super alpha release.

